Console reader
==============

.. automodule:: wexpect.console_reader


ConsoleReaderPipe
-----------------

.. autoclass:: ConsoleReaderPipe

  .. automethod:: __init__
  .. automethod:: read_loop
  .. automethod:: suspend_child
  .. automethod:: resume_child
  .. automethod:: refresh_console
  .. automethod:: terminate_child
  .. automethod:: isalive
  .. automethod:: write
  .. automethod:: createKeyEvent
  .. automethod:: initConsole
  .. automethod:: parseData
  .. automethod:: getConsoleOut
  .. automethod:: getCoord
  .. automethod:: getOffset
  .. automethod:: readConsole
  .. automethod:: readConsoleToCursor
  .. automethod:: interact
  .. automethod:: sendeof
  .. automethod:: create_connection
  .. automethod:: close_connection
  .. automethod:: send_to_host
  .. automethod:: get_from_host


ConsoleReaderSocket
-------------------

.. autoclass:: ConsoleReaderSocket

  .. automethod:: __init__
  .. automethod:: read_loop
  .. automethod:: suspend_child
  .. automethod:: resume_child
  .. automethod:: refresh_console
  .. automethod:: terminate_child
  .. automethod:: isalive
  .. automethod:: write
  .. automethod:: createKeyEvent
  .. automethod:: initConsole
  .. automethod:: parseData
  .. automethod:: getConsoleOut
  .. automethod:: getCoord
  .. automethod:: getOffset
  .. automethod:: readConsole
  .. automethod:: readConsoleToCursor
  .. automethod:: interact
  .. automethod:: sendeof
  .. automethod:: create_connection
  .. automethod:: close_connection
  .. automethod:: send_to_host
  .. automethod:: get_from_host
